@@ -7,7 +7,7 @@ package Comics::Plugin::CSectionComics;
 
 use parent qw(Comics::Fetcher::Cascade);
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 our $name    = "C-Section Comics";
 
@@ -30,18 +30,18 @@ our $name    = "C-Section Comics";
 our $url     = "http://www.csectioncomics.com/";
 our @patterns =
   (   qr{ <a \s+
-           href="(?<url>http://www.csectioncomics.com/archives)">
+           href="(?<url>https?://www.csectioncomics.com/archives)">
           Comics</a>
         }six,
       qr{ <td \s+
            class="archive-title"> \s*
           <a \s+
-	   href="(?<url>http://www.csectioncomics.com/comics/.*?)" \s+
+	   href="(?<url>https?://www.csectioncomics.com/comics/.*?)" \s+
            rel="bookmark"
         }six,
       qr{ <div \s+ id="comic"> \s+
 	  <img \s+
-	   src="(?<url>http://.*?.csectioncomics.com/csectioncomics/
+	   src="(?<url>https?://.*?.csectioncomics.com/csectioncomics/
 		       wp-content/uploads/\d+/\d+/
 		       (?<image>.*?\.\w+))" \s+
 	   alt="(?<alt>.*?)" \s+
