@@ -7,23 +7,17 @@ package Comics::Plugin::DoYouKnowFlo;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "0.01";
+our $VERSION = "1.01";
 
-sub register {
-
-    shift->SUPER::register
-      ( { name    => "Do you know Flo?",
-	  url     => "http://www.doyouknowflo.nl/",
-	  pat     =>
+our $name    = "Do you know Flo?";
+our $url     = "http://www.doyouknowflo.nl/";
+our $pattern =
 	    qr{ <img \s+
-		 class="alignright .*? size-full" \s+
+		 class="alignright .*? size-full .*?" \s+
 		 src="(?<url>http://doyouknowflo.nl/
 		        uploads/\d+/\d+/
 			(?<image>.*?\.\w+))" \s+
-		 alt="(?<alt>.*?)"
-	      }sx,
-	} );
-}
+	      }sx;
 
 # Important: Return the package name!
 __PACKAGE__;
