@@ -7,7 +7,7 @@ package Comics::Plugin::LeastICouldDo;
 
 use parent qw(Comics::Fetcher::Cascade);
 
-our $VERSION = "1.02";
+our $VERSION = "1.03";
 
 our $name    = "Least I Could Do";
 our $url     = "http://www.leasticoulddo.com/";
@@ -17,12 +17,12 @@ our @patterns =
 	 id="latest-comic">
       }six,
     qr{ <meta \s+
-         property="og:description" \s+
+         name="twitter:description" \s+
 	 content="(?<title>.*?)" \s*
 	/>
 	.*?
 	<meta \s+
-         property="og:image" \s+
+         name="twitter:image" \s+
          content="(?<url>https?://(?:www.)?leasticoulddo.com/wp-content/uploads/
                    \d+/\d+/(?<image>.*?\.\w+))" \s*
         />
